# Videowall

This is a Qt based video wall player. It can play an arbitrary number of movies at the same time in a user customizable configuration.

Playback features include:
* Select loop, step forward, or random videos from a library
* Customize volume and playback speed for each video
* Play, Pause, Mute the whole wall
* Keyboard control for a primary video
* Save wall layouts and automatic recovery of last layout
* Lots of options for customizing operation

## Requirements

* Python 3.9+
* PySide6
